# This overlay is used for overriding upstream packages.

self: super:

let
  nixpkgs-master = import <nixpkgs-master> { inherit (super) config; };

in {
  inherit nixpkgs-master;

  # alacritty = nixpkgs-master.alacritty;
  alacritty = super.stdenv.mkDerivation {
    name = "alacritty-custom";
    buildInputs = [ super.makeWrapper ];
    phases = "installPhase";
    installPhase = ''
      makeWrapper ${self.nixpkgs-master.alacritty}/bin/alacritty $out/bin/alacritty \
        --set-default WINIT_X11_SCALE_FACTOR 1.4
    '';
  };

  roxterm = super.stdenv.mkDerivation {
    name = "roxterm-custom";
    buildInputs = [ super.makeWrapper ];
    phases = "installPhase";
    installPhase = ''
      makeWrapper ${super.roxterm}/bin/roxterm $out/bin/roxterm \
        --add-flags "--separate"
    '';
  };

  # TODO: facetimehd is currfently broken (https://github.com/NixOS/nixpkgs/pull/72804)
  facetimehd-firmware = super.hello;

  qtile = self.nixpkgs-master.qtile.overrideAttrs(oldAttrs: {
    pythonPath = oldAttrs.pythonPath ++ (with self.python37Packages; [
      psutil
      dbus-python
      pyxdg
      mpd2
      # python-wifi
      # iwlib
      dateutil
      keyring
    ]);
  });

  btrbk = super.btrbk.overrideAttrs(attrs: rec {
    version = "0.30.0";
    src =  builtins.fetchurl {
      url = "https://digint.ch/download/btrbk/releases/${attrs.pname}-${version}.tar.xz";
      sha256 = "1wlp0z0ijv3cr155kp9c5l16dz4jf8h897ddnawaj9rj1zgfk9z8";
    };

    # version = "2020-12-30";
    # src = builtins.fetchurl {
    #   url = "https://github.com/digint/btrbk/archive/dd5991099ad778a3e0c5d11c770ad169c3095068.tar.gz";
    #   sha256 = "0iyjgr1nv1n7mpsrgkrmb85sz3ycimmfvvhj08cvkjgl0r1762sb";
    # };

    preFixup = ''
      wrapProgram $out/bin/btrbk \
        --set PERL5LIB $PERL5LIB \
        --prefix PATH ':' "${self.lib.makeBinPath (with self; [ btrfs-progs bash mbuffer openssh ])}"
    '';
  });
}
